@@ -5,10 +5,10 @@ require Exporter;
 use Carp qw/confess/;
 use Env::Path;
 use File::Basename;
-require Data::Dumper if defined ($ENV{DEBUG});
+require Data::Dumper if defined( $ENV{DEBUG} );
 
-our ($VERSION, $BINPATH, @ISA, @EXPORT);
-$VERSION = '1.03';
+our ( $VERSION, $BINPATH, @ISA, @EXPORT );
+$VERSION = '1.05';
 
 =head1 NAME
 
@@ -42,19 +42,16 @@ command:
 
 =cut
 
-@ISA = qw(Exporter);
-@EXPORT=qw($SCRIPTPATH $PATH $PERL5LIB &listScripts &getExecPrefix);
-our (
-     $SCRIPTPATH,
-     $PATH,
-     $PERL5LIB,
-    );
+@ISA    = qw(Exporter);
+@EXPORT = qw($SCRIPTPATH $PATH $PERL5LIB &listScripts &getExecPrefix);
+our ( $SCRIPTPATH, $PATH, $PERL5LIB, );
 
 sub import {
-    my $class=shift;
-    #@_ contains what could be passed on -MLoader=...; iv ever
-    init();
-    $class->export_to_level(1, $class, @_) ;
+	my $class = shift;
+
+	#@_ contains what could be passed on -MLoader=...; iv ever
+	init();
+	$class->export_to_level( 1, $class, @_ );
 }
 
 =head3 init()
@@ -65,60 +62,61 @@ setup libs and bin directories
 
 =cut
 
-sub init{
-  my $perlJavaHome;
-  $perlJavaHome=$ENV{PERLLOADERHOME} || $ENV{JAVAPERL};
-  $perlJavaHome="$ENV{HOME}/.perljava" unless defined $perlJavaHome;
-  
-  #$ENV{PATH}='';
-  $PATH = Env::Path->PATH;
-  $SCRIPTPATH = Env::Path->SCRIPTPATH;
-  $PERL5LIB = Env::Path->PERL5LIB;
+sub init {
+	my $perlJavaHome;
+	$perlJavaHome = $ENV{PERLLOADERHOME} || $ENV{JAVAPERL};
+	$perlJavaHome = "$ENV{HOME}/.perljava" unless defined $perlJavaHome;
 
-  #TODO change that from ENV
-  my @modules;
-  my %conffiles;
-  if($ENV{PERLLOADERMODULES}){
-    @modules=split /:/, $ENV{PERLLOADERMODULES};
-  }else{
-    foreach (<$perlJavaHome/conf/*.conf>){
-      open (CONFIGFILE, $_) or next;
-      my %entry=();
-      while (my $l = <CONFIGFILE>) {
-         if ($l =~ /^([^=]+)=(.*)/) {
-            my ($key, $val) = ($1, $2);
-            if ($key eq "prefix"){
-              $conffiles{$val}=\%entry;
-              push @modules, $val ;
-            }else{
-              $entry{$key}=$val;
-            }
-         }
-      }
-      close CONFIGFILE;
-    }
-    
-  }
-  require Data::Dumper if defined ($ENV{DEBUG});
-  printf Data::Dumper::Dumper(\%conffiles)."\n" if defined ($ENV{DEBUG});
-  foreach my $pjar (@modules) {
-    eval "use lib \"$pjar/$conffiles{$pjar}->{lib}\"";
-  }
-  #we wish to put the path from the given directory, but in the correct order, and in front of all other.
-  foreach my $pjar (reverse @modules) {
-    my $bin="$pjar/$conffiles{$pjar}->{bin}";
-    $bin=~ s/\/\//\//g;
-    $SCRIPTPATH->Prepend($bin) unless $SCRIPTPATH->Contains($bin);
-    $PATH->Prepend($bin) unless $PATH->Contains($bin);
-    my $lib="$pjar/$conffiles{$pjar}->{lib}";
-    $lib=~ s/\/\//\//g;
-    $PERL5LIB->Prepend($lib) unless $PERL5LIB->Contains($lib);
-  }
+	#$ENV{PATH}='';
+	$PATH       = Env::Path->PATH;
+	$SCRIPTPATH = Env::Path->SCRIPTPATH;
+	$PERL5LIB   = Env::Path->PERL5LIB;
+
+	#TODO change that from ENV
+	my @modules;
+	my %conffiles;
+	if ( $ENV{PERLLOADERMODULES} ) {
+		@modules = split /:/, $ENV{PERLLOADERMODULES};
+	}
+	else {
+		foreach (<$perlJavaHome/conf/*.conf>) {
+			open( CONFIGFILE, $_ ) or next;
+			my %entry = ();
+			while ( my $l = <CONFIGFILE> ) {
+				if ( $l =~ /^([^=]+)=(.*)/ ) {
+					my ( $key, $val ) = ( $1, $2 );
+					if ( $key eq "prefix" ) {
+						$conffiles{$val} = \%entry;
+						push @modules, $val;
+					}
+					else {
+						$entry{$key} = $val;
+					}
+				}
+			}
+			close CONFIGFILE;
+		}
+
+	}
+	require Data::Dumper                              if defined( $ENV{DEBUG} );
+	printf Data::Dumper::Dumper( \%conffiles ) . "\n" if defined( $ENV{DEBUG} );
+	foreach my $pjar (@modules) {
+		eval "use lib \"$pjar/$conffiles{$pjar}->{lib}\"";
+	}
+
+#we wish to put the path from the given directory, but in the correct order, and in front of all other.
+	foreach my $pjar ( reverse @modules ) {
+		my $bin = "$pjar/$conffiles{$pjar}->{bin}";
+		$bin =~ s/\/\//\//g;
+		$SCRIPTPATH->Prepend($bin) unless $SCRIPTPATH->Contains($bin);
+		$PATH->Prepend($bin)       unless $PATH->Contains($bin);
+		my $lib = "$pjar/$conffiles{$pjar}->{lib}";
+		$lib =~ s/\/\//\//g;
+		$PERL5LIB->Prepend($lib) unless $PERL5LIB->Contains($lib);
+	}
 
 }
 
-
-
 =head3 Dynamic::Loader::listScripts([patt])
 
 Return a list of commands following a pattern listScripts(), listScripts("*.pl"), listScripts("phe*")
@@ -127,24 +125,21 @@ The commands returned here are returned with a relative path to the package they
 
 =cut
 
-sub listScripts{
-  require File::Find::Rule;
-  my $patt=shift || '*';
+sub listScripts {
+	require File::Find::Rule;
+	my $patt = shift || '*';
 
-  my @tmp;
-  foreach my $p($SCRIPTPATH->List){
-    foreach ( File::Find::Rule->file()
-	      ->name( $patt )
-	      ->in( $p )){
-      next if /\/\.svn\//;
-      s/^$p([\/\\])?//;
-      push @tmp, $_;
-    }
-  }
-  return @tmp;
+	my @tmp;
+	foreach my $p ( $SCRIPTPATH->List ) {
+		foreach ( File::Find::Rule->file()->name($patt)->in($p) ) {
+			next if /\/\.svn\//;
+			s/^$p([\/\\])?//;
+			push @tmp, $_;
+		}
+	}
+	return @tmp;
 }
 
-
 =head3 Dynamic::Loader::getScript(relative_path)
 
 Return the complete path to the given scripts.
@@ -153,16 +148,35 @@ Contrary to listScripts(), this command must return exactly one script and will
 
 =cut
 
-sub getScript{
-  my $relPath=shift or confess "no relative path given";
-  my @tmp;
-  foreach ($SCRIPTPATH->List){
-    my $full="$_/$relPath";
-    push  @tmp, $full if -f $full;
-  }
-  confess "no script found for [$relPath]" unless @tmp;
-  confess "multiple scripts found (@tmp) for [$relPath]" if @tmp>1;
-  return $tmp[0];
+sub getScript {
+	my $relPath = shift or confess "no relative path given";
+	my @tmp;
+	foreach ( $SCRIPTPATH->List ) {
+		my $full = "$_/$relPath";
+		push @tmp, $full if -f $full;
+	}
+	confess "no script found for [$relPath]" unless @tmp;
+	my $contents;
+	if (@tmp) {
+		local $/;
+		foreach my $f (@tmp) {
+			open( FD, "<$f" ) or die "cannot read $f";
+			my $tmp = <FD>;
+			close FD;
+			unless ($contents) {
+				$contents = $tmp;
+			}
+			else {
+				if ( $contents ne $tmp ) {
+					confess
+"multiple scripts found with incompatible contents for [$relPath] in "
+					  . join(@tmp)
+					  if @tmp > 1;
+				}
+			}
+		}
+	}
+	return $tmp[0];
 }
 
 =head3 Dynamic::Loader::getLibs(relative_path)
@@ -171,17 +185,16 @@ Return the complete path to the given scripts + the complete perl prefix with pe
 
 =cut
 
+sub getLongScript {
+	my $relPath = shift or confess "no relative path given";
+	my $path    = getScript($relPath);
+	my $p5l     = "perl ";
+	foreach ( $PERL5LIB->List ) {
+		$p5l .= "-I$_ ";
+	}
 
-sub getLongScript{
-  my $relPath=shift or confess "no relative path given";
-  my $path=getScript($relPath);
-  my $p5l="perl ";
-  foreach ($PERL5LIB->List){
-  	$p5l.="-I$_ ";
-  }
-  
-  printf "---> $p5l$path \n" if defined ($ENV{DEBUG});
-  return "$p5l$path";
+	printf "---> $p5l$path \n" if defined( $ENV{DEBUG} );
+	return "$p5l$path";
 }
 
 =head3  Dynamic::Loader::getExecPrefix()
@@ -190,8 +203,8 @@ return an array to prepend to execution (perl, includes etc...)
 
 =cut
 
-sub getExecPrefix{
-  return ($^X);
+sub getExecPrefix {
+	return ($^X);
 }
 
 =head3 Dynamic::Loader::whence([pat])
@@ -200,8 +213,8 @@ return a list of commands with the full path corresponding to a pattern. Think o
 
 =cut
 
-sub whence{
-  return $SCRIPTPATH->Whence($_[0] or "*");
+sub whence {
+	return $SCRIPTPATH->Whence( $_[0] or "*" );
 }
 
 =head1 AUTHOR
@@ -261,7 +274,4 @@ under the same terms as Perl itself.
 
 =cut
 
-
-
-
-1; # End of Dynamic::Loader
+1;    # End of Dynamic::Loader
